@@ -2,6 +2,9 @@
 /* #undef LMMS_BUILD_WIN32 */
 /* #undef LMMS_BUILD_WIN64 */
 /* #undef LMMS_BUILD_APPLE */
+/* #undef LMMS_BUILD_OPENBSD */
+/* #undef LMMS_BUILD_FREEBSD */
+/* #undef LMMS_BUILD_HAIKU */
 
 /* #undef LMMS_HOST_X86 */
 #define LMMS_HOST_X86_64
@@ -9,9 +12,13 @@
 #define LMMS_HAVE_ALSA
 #define LMMS_HAVE_FLUIDSYNTH
 #define LMMS_HAVE_JACK
+#define LMMS_HAVE_WEAKJACK
+#define LMMS_HAVE_MP3LAME
 #define LMMS_HAVE_OGGVORBIS
 #define LMMS_HAVE_OSS
-/* #undef LMMS_HAVE_PORTAUDIO */
+/* #undef LMMS_HAVE_SNDIO */
+#define LMMS_HAVE_PORTAUDIO
+/* #undef LMMS_HAVE_SOUNDIO */
 #define LMMS_HAVE_PULSEAUDIO
 #define LMMS_HAVE_SDL
 #define LMMS_HAVE_STK
@@ -26,10 +33,6 @@
 #define LMMS_HAVE_SEMAPHORE_H
 #define LMMS_HAVE_SYS_SHM_H
 #define LMMS_HAVE_SYS_TIME_H
-#define LMMS_HAVE_SYS_WAIT_H
-#define LMMS_HAVE_SYS_SELECT_H
-#define LMMS_HAVE_STDARG_H
-#define LMMS_HAVE_SIGNAL_H
 #define LMMS_HAVE_SCHED_H
 #define LMMS_HAVE_SYS_SOUNDCARD_H
 /* #undef LMMS_HAVE_SOUNDCARD_H */
